fintorch.datasets.kaggle package
================================

Submodules
----------

fintorch.datasets.kaggle.downloader module
------------------------------------------

.. automodule:: fintorch.datasets.kaggle.downloader
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fintorch.datasets.kaggle
   :members:
   :undoc-members:
   :show-inheritance:
